[java-shib-shared] branch main updated: JSSH-71 - Remove the impact of the DestructableComponent Interface

Codeberg noreply at shibboleth.net
Tue Jul 14 16:22:11 UTC 2026


This is an automated email from the git hooks/post-receive script.

codeberg pushed a commit to branch main
in repository java-shib-shared.

View the commit online:
https://codeberg.org/Shibboleth/java-shib-shared/commit/4bd1bd0174f2e994986f88e1d8ef8e40599a9157

The following commit(s) were added to refs/heads/main by this push:
     new 4bd1bd01 JSSH-71 - Remove the impact of the DestructableComponent Interface
4bd1bd01 is described below

commit 4bd1bd0174f2e994986f88e1d8ef8e40599a9157
Author: Scott Cantor <scott at restingparrotsoftware.com>
AuthorDate: Tue Jul 14 12:21:58 2026 -0400

    JSSH-71 - Remove the impact of the DestructableComponent Interface
    
    https://shibboleth.atlassian.net/browse/JSSH-71
    
    Add more deprecations to various related logic.
    Adjust deprecations to reflect library version.
---
 .../AbstractIdentifiedInitializableComponent.java  |  2 +-
 .../shared/component/ComponentSupport.java         | 25 ++++++++++++++++-----
 .../component/DestroyedComponentException.java     | 26 ++++++++++++++++++++--
 .../shared/component/DestructableComponent.java    | 17 ++++++++++++--
 4 files changed, 60 insertions(+), 10 deletions(-)

diff --git a/shib-support/src/main/java/net/shibboleth/shared/component/AbstractIdentifiedInitializableComponent.java b/shib-support/src/main/java/net/shibboleth/shared/component/AbstractIdentifiedInitializableComponent.java
index 60fe492a..952cc73c 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/component/AbstractIdentifiedInitializableComponent.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/component/AbstractIdentifiedInitializableComponent.java
@@ -64,7 +64,7 @@ public abstract class AbstractIdentifiedInitializableComponent extends AbstractI
      * 
      * @deprecated
      */
-    @Deprecated(forRemoval = true, since = "5.3")
+    @Deprecated(forRemoval = true, since = "9.3")
     protected final void ifDestroyedThrowDestroyedComponentException() {
         super.ifDestroyedThrowDestroyedComponentException();
     }
diff --git a/shib-support/src/main/java/net/shibboleth/shared/component/ComponentSupport.java b/shib-support/src/main/java/net/shibboleth/shared/component/ComponentSupport.java
index 6b3e2208..a6c5d1db 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/component/ComponentSupport.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/component/ComponentSupport.java
@@ -21,7 +21,7 @@ import net.shibboleth.shared.logic.Constraint;
 import net.shibboleth.shared.primitive.StringSupport;
 
 /** Support class for working with {@link Component} objects. */
- at Deprecated(forRemoval = true, since = "5.0")
+ at Deprecated(forRemoval = true, since = "9.0")
 public final class ComponentSupport {
 
     /** Constructor. */
@@ -33,7 +33,10 @@ public final class ComponentSupport {
      * given object's {@link DestructableComponent#destroy()} method.
      * 
      * @param obj object to destroy, may be null
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.0")
     public static void destroy(@Nullable final Object obj) {
         if (obj == null) {
             return;
@@ -54,7 +57,10 @@ public final class ComponentSupport {
      * @param obj object to initialize, may be null
      * 
      * @throws ComponentInitializationException thrown if there is a problem initializing the object
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.0")
     public static void initialize(@Nullable final Object obj) throws ComponentInitializationException {
         if (obj == null) {
             return;
@@ -73,7 +79,10 @@ public final class ComponentSupport {
      * also an instance of {@link IdentifiedComponent}, the component's ID is included in the error message.
      * 
      * @param component component to check
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.0")
     public static void ifDestroyedThrowDestroyedComponentException(@Nonnull final DestructableComponent component) {
         Constraint.isNotNull(component, "Component cannot be null");
 
@@ -94,9 +103,12 @@ public final class ComponentSupport {
      * message.
      * 
      * @param component component to check
+     * 
+     * @deprecated
      */
-    public static void
-            ifNotInitializedThrowUninitializedComponentException(@Nonnull final InitializableComponent component) {
+    @Deprecated(forRemoval = true, since = "9.0")
+    public static void ifNotInitializedThrowUninitializedComponentException(
+            @Nonnull final InitializableComponent component) {
         Constraint.isNotNull(component, "Component cannot be null");
 
         if (!component.isInitialized()) {
@@ -115,9 +127,12 @@ public final class ComponentSupport {
      * message.
      * 
      * @param component component to check
+     * 
+     * @deprecated
      */
-    public static void
-            ifInitializedThrowUnmodifiabledComponentException(@Nonnull final InitializableComponent component) {
+    @Deprecated(forRemoval = true, since = "9.0")
+    public static void ifInitializedThrowUnmodifiabledComponentException(
+            @Nonnull final InitializableComponent component) {
         Constraint.isNotNull(component, "Component cannot be null");
 
         if (component.isInitialized()) {
diff --git a/shib-support/src/main/java/net/shibboleth/shared/component/DestroyedComponentException.java b/shib-support/src/main/java/net/shibboleth/shared/component/DestroyedComponentException.java
index b2781d41..ebd24f8d 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/component/DestroyedComponentException.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/component/DestroyedComponentException.java
@@ -14,13 +14,23 @@
 
 package net.shibboleth.shared.component;
 
-/** Exception thrown if a component has been destroyed and an attempt was made to use it. */
+/**
+ * Exception thrown if a component has been destroyed and an attempt was made to use it.
+ * 
+ * @deprecated
+ */
+ at Deprecated(forRemoval = true, since = "9.3")
 public class DestroyedComponentException extends RuntimeException {
 
     /** Serial version UID. */
     private static final long serialVersionUID = -2254557697221898493L;
 
-    /** Constructor. */
+    /**
+     * Constructor.
+     * 
+     * @deprecated
+     */
+    @Deprecated(forRemoval = true, since = "9.3")
     public DestroyedComponentException() {
         super();
     }
@@ -30,7 +40,10 @@ public class DestroyedComponentException extends RuntimeException {
      * to the string <code>has been destroyed</code>.
      * 
      * @param destroyedComponent the component that was destroyed
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.3")
     public DestroyedComponentException(final Object destroyedComponent) {
         super(destroyedComponent.toString() + " has been destroyed");
     }
@@ -39,7 +52,10 @@ public class DestroyedComponentException extends RuntimeException {
      * Constructor.
      * 
      * @param message exception message
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.3")
     public DestroyedComponentException(final String message) {
         super(message);
     }
@@ -48,7 +64,10 @@ public class DestroyedComponentException extends RuntimeException {
      * Constructor.
      * 
      * @param wrappedException exception to be wrapped by this one
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.3")
     public DestroyedComponentException(final Exception wrappedException) {
         super(wrappedException);
     }
@@ -58,7 +77,10 @@ public class DestroyedComponentException extends RuntimeException {
      * 
      * @param message exception message
      * @param wrappedException exception to be wrapped by this one
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval = true, since = "9.3")
     public DestroyedComponentException(final String message, final Exception wrappedException) {
         super(message, wrappedException);
     }
diff --git a/shib-support/src/main/java/net/shibboleth/shared/component/DestructableComponent.java b/shib-support/src/main/java/net/shibboleth/shared/component/DestructableComponent.java
index a00bdd8a..dcf6c35d 100644
--- a/shib-support/src/main/java/net/shibboleth/shared/component/DestructableComponent.java
+++ b/shib-support/src/main/java/net/shibboleth/shared/component/DestructableComponent.java
@@ -14,16 +14,29 @@
 
 package net.shibboleth.shared.component;
 
-/** A component which can be destroyed and its resources reclaimed. */
+/**
+ * A component which can be destroyed and its resources reclaimed.
+ *
+ * @deprecated
+ */
+ at Deprecated(forRemoval=true, since="9.3.0")
 public interface DestructableComponent extends Component {
 
     /**
      * Gets whether this component has been destroyed. Normally, once a component has been destroyed it cannot be used.
      * 
      * @return true iff the component has been destroyed
+     * 
+     * @deprecated
      */
+    @Deprecated(forRemoval=true, since="9.3.0")
     public boolean isDestroyed();
 
-    /** Destroys the component. */
+    /**
+     * Destroys the component.
+     * 
+     * @deprecated
+     */
+    @Deprecated(forRemoval=true, since="9.3.0")
     public void destroy();
 }
\ No newline at end of file

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list